
function Durner_New_HCF
close all
clc
global time depth F r w1 w2 a1 a2 n1 n2 m1 m2 para1 para2 para3 para4 para5 para6 xc1 xc2 
m = 0;
options=odeset('Maxstep',0.1);
nodes=101;
dx=depth/(nodes-1);
x = linspace(0,depth,nodes); %define spatial step
elements=time; 
dt=time/elements;
t = linspace(1,time,elements); %time step for solution output

sol = pdepe(m,@Durner_New_HCFpde,@Durner_New_HCFic,@Durner_New_HCFbc,x,t, options); % call the pdep function

u = sol(:,:,1); % solution for the Richards Equation of Suction head

% HCF to calculate hydraulic conductivity for the node n and node n-1
se1=(1+(a1.*-u(:,end-1)).^n1).^-m1;
se2=(1+(a2.*-u(:,end-1)).^n2).^-m2;
se3=(1+(a1.*-u(:,end)).^n1).^-m1;
se4=(1+(a2.*-u(:,end)).^n2).^-m2;

thelta1=(w1.*se1+w2.*se2).*(F-r)+r;
thelta2=(w1.*se3+w2.*se4).*(F-r)+r;

for i=1:length(thelta1)
 if xc2<=thelta1(i)
                 HCl1(i,1)=para1*thelta1(i)+para4;
            elseif thelta1(i,1)>=xc1 && thelta1(i)<=xc2
                 HCl1(i,1)=para2*thelta1(i)+para5;
          else 
                 HCl1(i,1)=para3*thelta1(i)+para6;
 end
end

for j=1:length(thelta2)
if xc2<thelta2(j)
                 HCl2(j,1)=para1*thelta2(j)+para4;
            elseif xc1<=thelta2(j) && thelta2(j)<=xc2
                 HCl2(j,1)=para2*thelta2(j)+para5;
          else 
                 HCl2(j,1)=para3*thelta2(j)+para6;
end
end
 k1=10.^HCl1;
 k2=10.^HCl2;
 
 % calculate outflow from the substrate (cm/min)
Q=-0.5*(k1+k2).*(u(:,end)-dx-u(:,end-1))./dx;
save ('Substrate_outflow','Q')


% convert the Richards Equation to the accepted form of the pdepe function --------------------------------------------------------------
function [c,f,s] = Durner_New_HCFpde(x,t,u,DuDx)
global F r w1 w2 a1 a2 n1 n2 m1 m2 ks para1 para2 para3 para4 para5 para6 xc1 xc2 Time Rainfall
if u>=0
    c=0;
    k=ks;
    s=0;
f = k.*DuDx-k;
else  
    
se1=(1+(a1.*-u).^n1).^-m1;
se2=(1+(a2.*-u).^n2).^-m2;

        
thelta=(w1.*se1+w2.*se2).*(F-r)+r;

if xc2<thelta
                 HCl=para1*thelta+para4;
            elseif xc1<=thelta && thelta<=xc2
                 HCl=para2*thelta+para5;
          else 
                 HCl=para3*thelta+para6;
end
            
k=10.^HCl;

f = k*DuDx-k;
d1=n1*m1*a1*(-a1*u)^(n1-1)/(1+(-a1*u)^n1)^(m1+1);
d2=n2*m2*a2*(-a2*u)^(n2-1)/(1+(-a2*u)^n2)^(m2+1);
c=(F-r)*(w1*d1+w2*d2);
s = 0;
end


% define initial condtion--------------------------------------------------------------
function u0 = Durner_New_HCFic(x)
global depth
o=-10; %normalised suction head at field capacity (cm)
u0=o+x-depth; % constant hydraulic head initial condition


% define boundary condition--------------------------------------------------------------
function [pl,ql,pr,qr] = Durner_New_HCFbc(xl,ul,xr,ur,t,x)
global Time Rainfall
index=find(t<=Time,1,'first')
R=Rainfall(index,1)/10; % set upper boundary as rainfall input (cm/min)
o=-10; % normalised suction head at field capacity (cm)
pl=R;
ql = 1;
pr =ur-o;
qr = 0;


